@@ -11,7 +11,8 @@ import tempfile
 from collections import defaultdict
 from itertools import chain
 from pathlib import Path
-from typing import Dict, Iterator, List, Optional, Tuple
+from textwrap import dedent
+from typing import Dict, Iterator, List, Optional, Set, Tuple
 
 from nbqa import (
     __version__,
@@ -30,7 +31,7 @@ CONFIG_FILES["isort"].extend([".isort.cfg"])
 CONFIG_FILES["pytest"].extend(["pytest.ini"])
 
 
-def _parse_args(raw_args: Optional[List[str]]) -> Tuple[str, str, List[str]]:
+def _parse_args(raw_args: Optional[List[str]]) -> Tuple[str, str, bool, List[str]]:
     """
     Parse command-line arguments.
 
@@ -45,6 +46,8 @@ def _parse_args(raw_args: Optional[List[str]]) -> Tuple[str, str, List[str]]:
         The third-party tool to run (e.g. :code:`mypy`).
     root_dirs
         The notebooks or directories to run third-party tool on.
+    allow_mutation
+        Whether to allow 3rd party tools to modify notebooks.
     kwargs
         Any additional flags passed to third-party tool (e.g. :code:`--quiet`).
 
@@ -65,6 +68,11 @@ def _parse_args(raw_args: Optional[List[str]]) -> Tuple[str, str, List[str]]:
     parser.add_argument(
         "root_dirs", nargs="+", help="Notebooks or directories to run command on."
     )
+    parser.add_argument(
+        "--allow-mutation",
+        action="store_true",
+        help="Allows `nbqa` to modify notebooks.",
+    )
     parser.add_argument("--version", action="version", version=f"nbQA {__version__}")
     try:
         args, kwargs = parser.parse_known_args(raw_args)
@@ -78,7 +86,8 @@ def _parse_args(raw_args: Optional[List[str]]) -> Tuple[str, str, List[str]]:
         sys.exit(0)  # pragma: nocover
     command = args.command
     root_dirs = args.root_dirs
-    return command, root_dirs, kwargs
+    allow_mutation = args.allow_mutation
+    return command, root_dirs, allow_mutation, kwargs
 
 
 def _get_notebooks(root_dir: str) -> Iterator[Path]:
@@ -437,13 +446,32 @@ def _get_arg(
     return arg
 
 
+def _get_mtimes(arg: Path) -> Set[float]:
+    """
+    Get the modification times of any converted notebooks.
+
+    Parameters
+    ----------
+    arg
+        Notebook or directory to run 3rd party tool on.
+
+    Returns
+    -------
+    Set
+        Modification times of any converted notebooks.
+    """
+    if not arg.is_dir():
+        return {os.path.getmtime(str(arg))}
+    return {os.path.getmtime(str(i)) for i in arg.rglob("*   .py")}
+
+
 def _run_command(
     command: str,
     root_dir: str,
     tmpdirname: str,
     nb_to_py_mapping: Dict[Path, Path],
     kwargs: List[str],
-) -> Tuple[str, str, int]:
+) -> Tuple[str, str, int, bool]:
     """
     Run third-party tool against given file or directory.
 
@@ -468,6 +496,8 @@ def _run_command(
         Captured stderr from running third-party tool.
     output_code
         Return code from third-party tool.
+    mutated
+        Whether 3rd party tool modified any files.
 
     Raises
     ------
@@ -484,6 +514,9 @@ def _run_command(
             f"Command `{command}` not found. "
             "Please make sure you have it installed before running nbQA on it."
         )
+
+    before = _get_mtimes(arg)
+
     output = subprocess.run(
         [command, str(arg), *kwargs],
         stderr=subprocess.PIPE,
@@ -491,14 +524,20 @@ def _run_command(
         cwd=tmpdirname,
         env=env,
     )
+
+    after = _get_mtimes(arg)
+    mutated = after != before
+
     output_code = output.returncode
 
     out = output.stdout.decode()
     err = output.stderr.decode()
-    return out, err, output_code
+    return out, err, output_code, mutated
 
 
-def _run_on_one_root_dir(root_dir: str, command: str, kwargs: List[str]) -> int:
+def _run_on_one_root_dir(
+    root_dir: str, command: str, allow_mutation: bool, kwargs: List[str]
+) -> int:
     """
     Run third-party tool on a single notebook or directory.
 
@@ -508,6 +547,8 @@ def _run_on_one_root_dir(root_dir: str, command: str, kwargs: List[str]) -> int:
         Notebook or directory to run 3rd-party tool on.
     command
         Third-party tool (e.g. :code:`mypy`)
+    allow_mutation
+        Whether to allow 3rd party tool to modify notebooks.
     kwargs
         Additional flags to pass to 3rd party tool
 
@@ -535,7 +576,7 @@ def _run_on_one_root_dir(root_dir: str, command: str, kwargs: List[str]) -> int:
         config.read(".nbqa.ini")
         if command in config.sections():
             kwargs.extend(config[command]["addopts"].split())
-        out, err, output_code = _run_command(
+        out, err, output_code, mutated = _run_command(
             command, root_dir, tmpdirname, nb_to_py_mapping, kwargs
         )
 
@@ -545,10 +586,24 @@ def _run_on_one_root_dir(root_dir: str, command: str, kwargs: List[str]) -> int:
             out, err = _replace_temp_python_file_references_in_out_err(
                 temp_python_file, notebook, out, err
             )
+            if mutated and not allow_mutation:
+                raise SystemExit(
+                    dedent(
+                        """\
+                        💥 Mutation detected, will not reformat!
 
-            put_magics_back_in.main(temp_python_file)
-            _ensure_cell_separators_remain(temp_python_file)
-            replace_source.main(temp_python_file, notebook)
+                        To allow for mutation, please use the `--allow-mutation` flag, e.g.
+
+                        ```
+                        nbqa black my_notebook.ipynb --allow-mutation
+                        ```
+                        """
+                    )
+                )
+            if mutated:
+                put_magics_back_in.main(temp_python_file)
+                _ensure_cell_separators_remain(temp_python_file)
+                replace_source.main(temp_python_file, notebook)
 
         sys.stdout.write(out)
         sys.stderr.write(err)
@@ -566,9 +621,11 @@ def main(raw_args: Optional[List[str]] = None) -> None:
         Command-line arguments (if calling this function directly), defaults to
         :code:`None` if calling via command-line.
     """
-    command, root_dirs, kwargs = _parse_args(raw_args)
+    command, root_dirs, allow_mutation, kwargs = _parse_args(raw_args)
 
-    output_codes = [_run_on_one_root_dir(i, command, kwargs) for i in root_dirs]
+    output_codes = [
+        _run_on_one_root_dir(i, command, allow_mutation, kwargs) for i in root_dirs
+    ]
 
     sys.exit(int(any(output_codes)))
 
