@@ -1,8 +1,9 @@
 """Uncomment magic IPython lines from converted notebook."""
 
+import fileinput
 from typing import TYPE_CHECKING
 
-if TYPE_CHECKING:  # pragma: nocover
+if TYPE_CHECKING:
     from pathlib import Path
 
 
@@ -15,15 +16,8 @@ def main(temp_python_file: "Path") -> None:
     temp_python_file
         Temporary Python file notebook was converted to.
     """
-    with open(str(temp_python_file), "r") as handle:
-        file = handle.readlines()
-
-    file = [
-        i
-        if i == "# %%\n" or not (i.startswith("# %") or i.startswith("# !"))
-        else i[2:]
-        for i in file
-    ]
-
-    with open(str(temp_python_file), "w") as handle:
-        handle.writelines(file)
+    for i in fileinput.input(str(temp_python_file), inplace=True):
+        if i == "# %%\n" or not (i.startswith("# %") or i.startswith("# !")):
+            print(i, end="")
+        else:
+            print(i[2:], end="")
